@@ -2,7 +2,7 @@
 
 Generate a multiscale spatial image."""
 
-__version__ = "0.4.0"
+__version__ = "0.4.2"
 
 import enum
 from typing import Union, Sequence, List, Optional, Dict, Mapping, Any, Tuple
@@ -75,13 +75,13 @@ class MultiscaleSpatialImage(DataTree):
                 scale_transform = []
                 translate_transform = []
                 for dim in image.dims:
-                    if len(image.coords[dim]) > 1:
+                    if len(image.coords[dim]) > 1 and np.issubdtype(image.coords[dim].dtype, np.number):
                         scale_transform.append(
                             float(image.coords[dim][1] - image.coords[dim][0])
                         )
                     else:
                         scale_transform.append(1.0)
-                    if len(image.coords[dim]) > 0:
+                    if len(image.coords[dim]) > 0 and np.issubdtype(image.coords[dim].dtype, np.number):
                         translate_transform.append(float(image.coords[dim][0]))
                     else:
                         translate_transform.append(0.0)
@@ -192,7 +192,7 @@ def to_multiscale(
     # https://github.com/pydata/xarray/issues/5219
     if "chunks" in current_input.encoding:
         del current_input.encoding["chunks"]
-    data_objects = {f"multiscales/scale0": current_input.to_dataset(name=image.name)}
+    data_objects = {f"multiscales/scale0": current_input.to_dataset(name=image.name, promote_attrs=True)}
 
     if method is None:
         method = Methods.XARRAY_COARSEN
@@ -235,7 +235,7 @@ def to_multiscale(
             downscaled = downscaled.chunk(out_chunks)
 
             data_objects[f"multiscales/scale{factor_index+1}"] = downscaled.to_dataset(
-                name=image.name
+                name=image.name, promote_attrs=True
             )
             current_input = downscaled
     elif method is Methods.ITK_BIN_SHRINK:
@@ -310,7 +310,7 @@ def to_multiscale(
             )
             downscaled = downscaled.chunk(out_chunks)
             data_objects[f"multiscales/scale{factor_index+1}"] = downscaled.to_dataset(
-                name=image.name
+                name=image.name, promote_attrs=True
             )
             current_input = downscaled
 
